summaryrefslogtreecommitdiffstats
path: root/tdeprint/tests
diff options
context:
space:
mode:
Diffstat (limited to 'tdeprint/tests')
-rw-r--r--tdeprint/tests/drawdemo.cpp4
-rw-r--r--tdeprint/tests/helpwindow.cpp6
-rw-r--r--tdeprint/tests/helpwindow.h2
-rw-r--r--tdeprint/tests/main.cpp2
-rw-r--r--tdeprint/tests/richpage.cpp4
5 files changed, 9 insertions, 9 deletions
diff --git a/tdeprint/tests/helpwindow.cpp b/tdeprint/tests/helpwindow.cpp
index 87603ceb5..bee755d20 100644
--- a/tdeprint/tests/helpwindow.cpp
+++ b/tdeprint/tests/helpwindow.cpp
@@ -19,8 +19,8 @@
#include <tqtoolbutton.h>
#include <tqiconset.h>
#include <tqfile.h>
-#include <textstream.h>
-#include <stylesheet.h>
+#include <tqtextstream.h>
+#include <tqstylesheet.h>
#include <tqmessagebox.h>
#include <tqfiledialog.h>
#include <tqapplication.h>
@@ -278,7 +278,7 @@ void HelpWindow::print()
TQRect view( body );
int page = 1;
do {
- richText.draw( &p, body.left(), body.top(), view, colorGroup() );
+ richText.draw( &p, body.left(), body.top(), view, tqcolorGroup() );
view.moveBy( 0, body.height() );
p.translate( 0 , -body.height() );
p.setFont( font );
diff --git a/tdeprint/tests/helpwindow.h b/tdeprint/tests/helpwindow.h
index 5c4a16c62..c444b8144 100644
--- a/tdeprint/tests/helpwindow.h
+++ b/tdeprint/tests/helpwindow.h
@@ -12,7 +12,7 @@
#define HELPWINDOW_H
#include <kmainwindow.h>
-#include <textbrowser.h>
+#include <tqtextbrowser.h>
#include <tqstringlist.h>
#include <tqmap.h>
#include <tqdir.h>
diff --git a/tdeprint/tests/main.cpp b/tdeprint/tests/main.cpp
index a89bcd13a..a1dc6b5e0 100644
--- a/tdeprint/tests/main.cpp
+++ b/tdeprint/tests/main.cpp
@@ -11,7 +11,7 @@
#include "helpwindow.h"
#include <kapplication.h>
#include <tqwindowsstyle.h>
-#include <stylesheet.h>
+#include <tqstylesheet.h>
#include <stdlib.h>
diff --git a/tdeprint/tests/richpage.cpp b/tdeprint/tests/richpage.cpp
index d611e4ecd..30da712de 100644
--- a/tdeprint/tests/richpage.cpp
+++ b/tdeprint/tests/richpage.cpp
@@ -4,7 +4,7 @@
#include <tqspinbox.h>
#include <tqcombobox.h>
#include <tqfontdatabase.h>
-#include <layout.h>
+#include <tqlayout.h>
RichPage::RichPage(TQWidget *parent, const char *name)
: KPrintDialogPage(parent,name)
@@ -23,7 +23,7 @@ RichPage::RichPage(TQWidget *parent, const char *name)
QFontDatabase db;
QStringList fonts = db.families();
fontname_->insertStringList(fonts);
- fontname_->setCurrentItem(fonts.findIndex(TQString::fromLatin1("times")));
+ fontname_->setCurrentItem(fonts.findIndex(TQString::tqfromLatin1("times")));
if (fontname_->currentItem() < 0) fontname_->setCurrentItem(0);
QLabel *l1 = new TQLabel("Margin:",this);
diff --git a/tdeprint/tests/drawdemo.cpp b/tdeprint/tests/drawdemo.cpp
index 443cc89e8..20fc3d12e 100644
--- a/tdeprint/tests/drawdemo.cpp
+++ b/tdeprint/tests/drawdemo.cpp
@@ -78,7 +78,7 @@ void drawFonts( TQPainter *p )
//
// This function draws some shapes
//
void drawShapes( TQPainter *p )
@@ -115,7 +115,7 @@ struct DrawThing {
DrawThing ourDrawFunctions[] = {
{ drawColorWheel, "Draw color wheel" },
{ drawFonts, "Draw fonts" },
- { drawShapes, "Draw shapes" },
+ { drawShapes, "Draw tqshapes" },
{ 0, 0 } };
@@ -78,7 +78,7 @@ void drawFonts( TQPainter *p )
//
-// This function draws some shapes
+// This function draws some tqshapes
//
void drawShapes( TQPainter *p )